==> mutual_credit-5.0.0-beta2.tar.gz: mutual_credit/src/Form/WalletAddForm.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Mcapi;
use Drupal\mcapi\Entity\Wallet;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder to create a new wallet for a given ContentEntity.
 */
class WalletAddForm extends ContentEntityForm {

  private $holder;

  /**
   * {@inheritdoc}
   */
  public function __construct($entity_repository, $entity_type_bundle_info, $time) {
    parent::__construct($entity_repository, $entity_type_bundle_info, $time);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity.repository'),
      $container->get('entity_type.bundle.info'),
      $container->get('datetime.time')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wallet_add_form';
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $form['#title'] = $this->t("New wallet for @entity_type '%title'",
      [
        '@entity_type' => $this->entity->getHolder()->getEntityType()->getLabel(),
        '%title' => $this->entity->getHolder()->label(),
      ]
      );
    $form['wid'] = [
      '#type' => 'value',
      '#value' => NULL,
    ];
    $form['name'] = [
      '#type' => 'textfield',
      '#title' => t('Name or purpose of wallet'),
      '#default_value' => '',
      '#required' => '',
      '#access' => !Mcapi::oneWalletMode($this->entity->getHolder())
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = t('Create');
    return $actions;
  }


  /**
   * {@inheritdoc}
   */
  public function __buildEntity(array $form, FormStateInterface $form_state) {
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    $entity = parent::buildEntity($form, $form_state);
    $entity->holder_entity_type->value = $this->entity->getHolder()->getEntityTypeId();
    $entity->holder_entity_id->value = $this->entity->getHolder()->id();
    return $entity;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    // Just check that the name isn't the same.
    // This unique check would be better in a walletStorageController.
    $values = $form_state->getValues();
    $query = $this->entityTypeManager
      ->getStorage('mcapi_wallet')
      ->getQuery()
      ->condition('name', $values['name']);

    if (!$this->config('mcapi.settings')->get('unique_names')) {
      $query->condition('holder_entity_id', $this->entity->getHolder()->id());
      $query->condition('holder_entity_type', $this->entity->getHolder()->getEntityTypeId());
    }
    if ($query->execute()) {
      $form_state->setErrorByName(
        'name',
        t("The wallet name '%name' is already used.", ['%name' => $values['name']])
      );
    }
    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $this->entity->save();
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
  }

    /**
   * {@inheritdoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $params = $route_match->getParameters()->all();

    $values = [
      'holder_entity_type' => reset($params)->getEntityTypeId(),
      'holder_entity_id' => reset($params)->id()
    ];
    return Wallet::create($values);
  }

}

==> mutual_credit-5.1.0-beta2.tar.gz: mutual_credit/src/Form/WalletAddForm.php <==
<?php

namespace Drupal\mcapi\Form;

use Drupal\mcapi\Entity\Wallet;
use Drupal\Core\Entity\ContentEntityForm;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Routing\RouteMatchInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Form builder to create a new wallet for a given ContentEntity.
 */
class WalletAddForm extends ContentEntityForm {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'wallet_add_form';
  }

  /**
   * {@inheritdoc}
   */
  public function form(array $form, FormStateInterface $form_state) {
    $holder = $this->entity->holder->entity; // cannot be null.
    $form['#title'] = $this->t("New wallet for @entity_type '%title'",
      [
        '@entity_type' => $holder->getEntityType()->getLabel(),
        '%title' => $holder->label(),
      ]
    );
    $form = parent::form($form, $form_state);
    $form['name']['widget'][0]['value']['#placeholder'] = $this->entity->holder->entity->label() . ' ('.t('suggested').')';
    $form['holder']['#access'] = FALSE;
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  protected function actions(array $form, FormStateInterface $form_state) {
    $actions = parent::actions($form, $form_state);
    $actions['submit']['#value'] = t('Create');
    return $actions;
  }

  /**
   * {@inheritdoc}
   */
  public function save(array $form, FormStateInterface $form_state) {
    $this->entity->save();
    $form_state->setRedirectUrl($this->entity->toUrl('edit-form'));
    $this->messenger()->addStatus($this->t('The wallet was created'));
  }

    /**
   * {@inheritdoc}
   */
  public function getEntityFromRouteMatch(RouteMatchInterface $route_match, $entity_type_id) {
    $params = $route_match->getParameters()->all();
    $values = ['holder' => reset($params)];
    return Wallet::create($values);
  }

}
